%global python3_pkgversion 3.12
%bcond_with shell

Name:           python%{python3_pkgversion}-netaddr-epel
Version:        1.2.1
Release:        1%{?dist}
Summary:        A pure Python network address representation and manipulation library

License:        BSD-3-Clause
URL:            https://github.com/drkjam/netaddr
Source0:        https://pypi.python.org/packages/source/n/netaddr/netaddr-%{version}.tar.gz

BuildRequires:  pyproject-rpm-macros
BuildArch:      noarch

%global desc A network address manipulation library for Python\
\
Provides support for:\
\
Layer 3 addresses\
\
 * IPv4 and IPv6 addresses, subnets, masks, prefixes\
 * iterating, slicing, sorting, summarizing and classifying IP networks\
 * dealing with various ranges formats (CIDR, arbitrary ranges and globs, nmap)\
 * set based operations (unions, intersections etc) over IP addresses and\
   subnets\
 * parsing a large variety of different formats and notations\
 * looking up IANA IP block information\
 * generating DNS reverse lookups\
 * supernetting and subnetting\
\
Layer 2 addresses\
\
 * representation and manipulation MAC addresses and EUI-64 identifiers\
 * looking up IEEE organisational information (OUI, IAB)\
 * generating derived IPv6 addresses


%global _description\
%{desc}

%description %_description

%package -n python%{python3_pkgversion}-netaddr
Summary: A pure Python network address representation and manipulation library
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-wheel
# No python%{python3_pkgversion}-sphinx yet
BuildRequires:  python3-sphinx
BuildRequires:  python%{python3_pkgversion}-pytest

%description -n python%{python3_pkgversion}-netaddr
%{desc}

%if %{with shell}
%package -n python%{python3_pkgversion}-netaddr-shell
Summary: An IPython-based shell environment for the netaddr library
Requires:  python%{python3_pkgversion}-netaddr = %{version}-%{release}
Requires:  python%{python3_pkgversion}-ipython

%description -n python%{python3_pkgversion}-netaddr-shell
An IPython-based shell environment for the netaddr library
%endif

%prep
%setup -q -n netaddr-%{version}
sed -i -e /sphinx_issue/d -e /furo/d docs/source/conf.py

# Make rpmlint happy, rip out python shebang lines from most python
# modules
find netaddr -name "*.py" | \
  xargs sed -i -e '1 {/^#!\//d}'

%build
%pyproject_wheel

#docs
pushd docs
PYTHONPATH='../' sphinx-build -b html -d build/doctrees source python3/html
rm -f python3/html/.buildinfo
popd

%install
%pyproject_install
%pyproject_save_files netaddr
%if !%{with shell}
rm %{buildroot}%{_bindir}/netaddr
%endif

%check
py.test-%{python3_version}

%files -n python%{python3_pkgversion}-netaddr -f %{pyproject_files}
%license COPYRIGHT.rst
%doc AUTHORS.rst CHANGELOG.rst README.rst THANKS.rst
%doc docs/python3/html

%if %{with shell}
%files -n python%{python3_pkgversion}-netaddr-shell
%{_bindir}/netaddr
%endif

%changelog
* Thu May 23 2024 Orion Poplawski <orion@nwra.com> - 1.2.1-1
- Build for Python 3.12
